frigg-runner |Build status| |Coverage status| |pypi version|
============================================================

Frigg runner, execute .frigg.yml file localy.

    $ pip install frigg-runner

Run the tasks:

    $ frigg


--------------

MIT © frigg.io


.. |Build status| image:: https://ci.frigg.io/badges/frigg/frigg-runner/
        :target: https://ci.frigg.io/frigg/frigg-runner/

.. |Coverage status| image:: http://ci.frigg.io/badges/coverage/frigg/frigg-runner/
        :target: https://ci.frigg.io/frigg/frigg-runner/

.. |pypi version| image:: https://badge.fury.io/py/frigg-runner.png
    :target: http://badge.fury.io/py/frigg-runner
